// OCP NIC 3.0 
// PRSNT pin usage key pseudo code for SFF and LFF - 0v86



// Handle SFF slot
if (OCP_SLOT == SFF){

	if (NUM_HOSTS == 1 && NUM_SOCKETS == 1){				// Single host, single socket configurations
	  switch (PRIMARY_CONN_PRSNTB){
		0b1111:	// No card installed
		0b1110: // SFF 2C+ 1 x8 Option A, 1 x4, 1 x2, and 1 x1 cards
		0b1100: // SFF 2C+ 1 x8 Option D, and SFF 4C+ 1 x16 Option D cards
		0b0111: // SFF 4C+ 1 x16 Option A cards
		0b0101:	// SFF 4C+ 1 x16 Option B cards
		0b0100: // SFF 4C+ 1 x16 Option C cards
			// Configure SFF OCP NIC 3.0 slot as 1 x16
			break;

		0b1101: // SFF 2C+ 1 x8 Option B, and SFF 4C+ 2 x8 Option B cards
		0b0110: // SFF 4C+ 2 x8 Option A cards
			// Configure SFF OCP NIC 3.0 slot as 2 x8
			break;

		0b0011: // SFF 4C+ 4 x4 cards
		0b1001: // SFF 2C+ 4 x2 cards
		0b1010: // SFF 2C+ 2 x4 cards
			// Configure SFF OCP NIC 3.0 slot as 4 x4
			break;

		default:
			No valid configuration
	  }
	}

	if ( (NUM_HOSTS == 1 && NUM_SOCKETS == 2) ||		// Single host, dual socket configurations
		 (NUM_HOSTS == 1 && NUM_SOCKETS == 4) ||		// Single host, quad socket configurations
		 (NUM_HOSTS == 2 && NUM_SOCKETS == 2) ||		// Dual host, dual socket configurations
		 (NUM_HOSTS == 4 && NUM_SOCKETS == 4) )	{		// Quad host, quad socket configurations

		switch (PRIMARY_CONN_PRSNTB){
			0b1111: // No card installed
			0b1110: // SFF 2C+ 1 x8 Option A, 1 x4, 1 x2, and 1 x1 cards
			0b1101: // SFF 2C+ 1 x8 Option B, and SFF 4C+ 2 x8 Option B cards
			0b1100: // SFF 2C+ 1 x8 Option D, and SFF 4C+ 1 x16 Option D cards
			0b1010: // SFF 2C+ 2 x4 cards
			0b1001: // SFF 2C+ 4 x2 cards
			0b0111: // SFF 4C+ 1 x16 Option A cards
			0b0110: // SFF 4C+ 2 x8 Option A cards
			0b0101:	// SFF 4C+ 1 x16 Option B cards
			0b0100: // SFF 4C+ 1 x16 Option C cards
			0b0011: // SFF 4C+ 4 x4 cards
				// Single host, dual socket configurations
				if (NUM_HOSTS == 1 && NUM_SOCKETS == 2) {
					// Configure SFF OCP NIC 3.0 slot as 2 x8 -- x8 per socket
				}

				// Single host, quad socket configurations
				if (NUM_HOSTS == 1 && NUM_SOCKETS == 4) {
					if (FIRST_8_PCIE_LANES){
						// Configure SFF OCP NIC 3.0 slot as 4 x2 -- x2 per socket on the first 8 lanes
					} else {
						// Configure SFF OCP NIC 3.0 slot as 4 x4 -- x4 per socket
					}
				}

				// Dual host, dual socket configurations
				if (NUM_HOSTS == 2 && NUM_SOCKETS == 2) {
					// Configure SFF OCP NIC 3.0 slot as 2 x8 -- x8 per socket
				}

				// Quad host, quad socket configurations
				if (NUM_HOSTS == 4 && NUM_SOCKETS == 4) {
					if(FIRST_8_PCIE_LANES) {
						// Configure SFF OCP NIC 3.0 slot as 4 x2 -- x2 per socket on the first 8 lanes
					} else {
						// Configure SFF OCP NIC 3.0 slot as 4 x4 -- x4 per socket
					}
				}
				break;

			default:
				// No valid configuration
		}
    }
}

// Handle LFF slot
if (OCP_SLOT == LFF) {

	if (NUM_HOSTS == 1 && NUM_SOCKETS == 1) {					// Single host, single socket configurations
	
		if ( (PRIMARY_CONN_PRSNTB == SECONDARY_CONN_PRSNTB) ||  						// Handle bulk of LFF cases where the Primary and Secondary connector values are equal.
			 (PRIMARY_CONN_PRSNTB == 0b0000 && SECONDARY_CONN_PRSNTB == 0b0001) ) {		// Handle case for Primary == 0b0000 and Secondary == 0b0001.
			switch (PRIMARY_CONN_PRSNTB){
				0b1111: // No card installed
				0b0111: // LFF 2 x16 Option A
				0b0110: // LFF 4 x8 Option A
				0b0101: // LFF 2 x16 Option B
				0b0100: // LFF 2 x16 Option C
				0b0000: // LFF 1 x32 Option A
					// Configure host 0 as 1x32
					break;

				default:
					No valid configuration
			}
		}
	}

	if (NUM_HOSTS == 1 && NUM_SOCKETS == 2) {				// Single host, dual socket configurations
		if ( (PRIMARY_CONN_PRSNTB == SECONDARY_CONN_PRSNTB) ||  						// Handle bulk of LFF cases where the Primary and Secondary connector values are equal.
			 (PRIMARY_CONN_PRSNTB == 0b0000 && SECONDARY_CONN_PRSNTB == 0b0001) ) {		// Handle case for Primary == 0b0000 and Secondary == 0b0001.
			switch (PRIMARY_CONN_PRSNTB){
				0b1111: // No card installed
				0b0111: // LFF 2 x16 Option A
				0b0101: // LFF 2 x16 Option B
				0b0100: // LFF 2 x16 Option C
				0b0000: // LFF 1 x32 Option A
					// Configure LFF OCP NIC 3.0 slot as 2x16
					break;

				0b0110: // LFF 4 x8 Option A
					// Configure LFF OCP NIC 3.0 slot as 4x8
					break;

				default:
					// No valid configuration
			}
		}
	}

	if ( (NUM_HOSTS == 1 && NUM_SOCKETS == 4) ||			// Single host, quad socket configurations
	 	 (NUM_HOSTS == 1 && NUM_SOCKETS == 8) ||			// Single host, octal socket configurations	
	 	 (NUM_HOSTS == 2 && NUM_SOCKETS == 4) || 			// Dual host, quad socket configurations
		 (NUM_HOSTS == 4 && NUM_SOCKETS == 8) ) {			// Quad host, octal socket configurations
		
		if ( (PRIMARY_CONN_PRSNTB == SECONDARY_CONN_PRSNTB) ||							// Handle bulk of LFF cases where the Primary and Secondary connector values are equal.
			 (PRIMARY_CONN_PRSNTB == 0b0000 && SECONDARY_CONN_PRSNTB == 0b0001) ) { 	// Handle case for Primary == 0b0000 and Secondary == 0b0001.
			switch (PRIMARY_CONN_PRSNTB ){
				0b1111: // No card installed
				0b0111: // LFF 2 x16 Option A
				0b0110: // LFF 4 x8 Option A
				0b0101: // LFF 2 x16 Option B
				0b0100: // LFF 2 x16 Option C
				0b0000: // LFF 1 x32 Option A
					if ( (NUM_HOSTS == 1 && NUM_SOCKETS == 4) ||	// Single host, quad socket configurations
						 (NUM_HOSTS == 2 && NUM_SOCKETS == 4) ){	// Dual host, quad socket configurations
						// Configure LFF OCP NIC 3.0 slot as 4x8
					}

					if ( (NUM_HOSTS == 1 && NUM_SOCKETS == 8) || 	// Single host, octal socket configurations	
						 (NUM_HOSTS == 4 && NUM_SOCKETS == 8) ) {	// Quad host, octal socket configurations
							 
						if(FIRST_8_PCIe_LANES){
							// Configure LFF OCP NIC 3.0 slot as 8x2 - first 8 lanes per connector
						} else {
							// Configure LFF OCP NIC 3.0 slot as 8x4
						}
					}

					break;

				default:
					// No valid configuration
			}
		}
	}
}





